#!/usr/bin/perl -w
# fw_salert.pl - A firewall alert tool.
# @(#)fw_salert.pl v1.0 09 AUG 2000 Rob Thomas robt@cymru.com
#
# fw_salert.pl utilizes the syslog service to issue alerts based on a user-
# defined rule.  The configuration is simple.
#      1. Click on Policy->Properties in the FW-1 GUI tool.
#      2. Select the Log and Alert tab.
#      3. Edit the User Defined Alert Command field, and insert the fully
#         qualified path to this tool, e.g. /usr/local/fw-1/fw_salert.pl
#      4. Insert a rule in the rule base such as:
# Source  Destination  Service  Action  Track         Install On  Time  Comment
#  Any      Firewall    <pick>   Drop    UserDefined   Gateways    Any   <cmt>
#         The <pick> field should be replaced with all services for which
#         an alert is required, e.g. telnet, finger, or POP.  The <cmt>
#         field should be replaced by the date of rule insertion and the
#         name and/or e-mail address of the rule creator.  Comments are
#         a Good Thing[tm].
#         Save the rule base and apply it to the firewalls.  Remember
#         that fw_salert.pl must be installed on every firewall to which
#         the new rule is pushed!
#      5. Configure /etc/syslog.conf to send the data to the desired
#         destination.  This could be a local file, root (if root is
#         logged in), or a remote host.  A remote host and a local file
#         is a safe combination.  With the Nokia platform, limited disk
#         space likely dictates that the data should be sent to a remote
#         host, such as the EMC.  The syslog facility and level should
#         be selected, as noted in the source code below.  Remember to
#         insert TABs between the facility.level pair and the destination.
#         The syslog service does not like spaces!  Here is a sample
#         syslog.conf entry:
# local3.debug				/var/adm/fwalertlog
#         Or to send it to a remote host:
# local3.debug				@remote-host-name
#         Don't forget to send a SIGHUP to the syslogd process.  Verify
#         that syslogd is using the newly created file (if you are using
#         a local file) with fuser <FILENAME>.
#
# Depending on your OS, you may need to edit the she-bang for perl.
#

use Sys::Syslog;

# Edit both $FACILITY and $LEVEL to suit your local requirements.

$FACILITY="local3";
$LEVEL="debug";

@fwalert = split(' ', <STDIN>, 17);

openlog("FW-ALERT", "ndelay", "$FACILITY");

syslog("$LEVEL","$fwalert[3] on $fwalert[4]: $fwalert[0] $fwalert[1] $fwalert[9]:$fwalert[15] to $fwalert[11]:$fwalert[13]");

closelog();

exit(0);


